==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let BollingerBandWidthIndicator = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicator extends StrategyBasedIndicator {
        get_t4() {
            return new BollingerBandWidthIndicatorStrategy();
        }
        get t4() {
            return this.get_t4();
        }
        get_uh() {
            return BollingerBandWidthIndicator.$;
        }
        get uh() {
            return this.get_uh();
        }
        get uq() {
            return typeGetValue(this.c(BollingerBandWidthIndicator.ut));
        }
        set uq(a) {
            this.h(BollingerBandWidthIndicator.ut, a);
        }
        ua() {
            return this.uq;
        }
        get up() {
            return this.c(BollingerBandWidthIndicator.us);
        }
        set up(a) {
            this.h(BollingerBandWidthIndicator.us, a);
        }
        t8() {
            return this.up;
        }
    }
    BollingerBandWidthIndicator.$t = /*@__PURE__*/ markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.ut = /*@__PURE__*/ StrategyBasedIndicator.um(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.us = /*@__PURE__*/ StrategyBasedIndicator.ul(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
})();

==> igniteui-react-charts-16.16.3.tgz: package/esm2015/lib/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let BollingerBandWidthIndicator = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicator extends StrategyBasedIndicator {
        get_uh() {
            return new BollingerBandWidthIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return BollingerBandWidthIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get u3() {
            return typeGetValue(this.c(BollingerBandWidthIndicator.u6));
        }
        set u3(a) {
            this.h(BollingerBandWidthIndicator.u6, a);
        }
        un() {
            return this.u3;
        }
        get u2() {
            return this.c(BollingerBandWidthIndicator.u5);
        }
        set u2(a) {
            this.h(BollingerBandWidthIndicator.u5, a);
        }
        ul() {
            return this.u2;
        }
    }
    BollingerBandWidthIndicator.$t = /*@__PURE__*/ markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.u6 = /*@__PURE__*/ StrategyBasedIndicator.uz(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.u5 = /*@__PURE__*/ StrategyBasedIndicator.uy(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
})();
